# `relationalai.Model.name`

An attribute assigned to the [model's](./README.md) name.

## Returns

A [`string`](https://docs.python.org/3/library/stdtypes.html#text-sequence-type-str) object.

## Example

```python
import relational as rai

model = rai.model("myModel")

print(model.name)
# Output:
# 'myModel'
```
